TODO:
- Test Tarjan’s algorithm (and all other functions, but this especially).
- Actually, clone petgraph’s
testsandbenchesdirectories.
- Actually, clone petgraph’s
- Fill up last 5 traits.
- Specifically Hypergraph Neural Networks.
- Do temporal graphs.
- Spectral graph stuff. I have the book now, so nice.
- Parallelism?
Modules
- algo
- graph
- macros
- This module is heavily inspired by the
rshypercrate. - prelude
- traits
- Most of the functionality of this library is encapsulated in these traits. A quick overview:
Macros
- hyperedge
- The
hyperedgemacro streamlines the definition of hyperedges in a hypergraph. - hypergraph
- the [
hypergraph] macro works to aide the in the creation of hypergraphs by allowing users to define nodes and edges in a hypergraph in a more declarative way. - hypernode
- the [
hypernode] macro streamlines the process of inserting nodes into a hypergraph. - impl_
graph_ basics